aboutsummaryrefslogtreecommitdiff
path: root/tools/dist-scummvm.sh
diff options
context:
space:
mode:
Diffstat (limited to 'tools/dist-scummvm.sh')
-rwxr-xr-xtools/dist-scummvm.sh4
1 files changed, 2 insertions, 2 deletions
diff --git a/tools/dist-scummvm.sh b/tools/dist-scummvm.sh
index f4948ded21..de76c9f6a9 100755
--- a/tools/dist-scummvm.sh
+++ b/tools/dist-scummvm.sh
@@ -1,6 +1,6 @@
#!/bin/sh -e
#
# dist-module.sh - make release tarballs for one CVS module
#
# Largely based on dist-fink.sh, Copyright (c) 2001 Christoph Pfisterer.
# Modified to use Subversion instead of CVS by Max Horn in 2007.
@@ -63,7 +63,7 @@ fi
### check code out from SVN
# TODO: Add support for making tarballs from trunk / branches?
-echo "Exporting module $module, tag $tag from CVS:"
+echo "Exporting module $module, tag $tag from SVN:"
svn export "$svnroot/$module/tags/$tag" $fullname
if [ ! -d $fullname ]; then
echo "SVN export failed, directory $fullname doesn't exist!"
@@ -1,6 +1,6 @@
#!/bin/sh -e
#
-# dist-module.sh - make release tarballs for one CVS module
+# dist-module.sh - make release tarballs for one SVN module
#
# Largely based on dist-fink.sh, Copyright (c) 2001 Christoph Pfisterer.